==> igniteui-angular-core-17.3.0.tgz: package/esm2015/lib/WebPaneDragEndEventArgsDetailDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebDockManagerPaneDescriptionMetadata } from "./WebDockManagerPaneDescriptionMetadata";
import { WebPaneDragEndEventArgsDetailDescription } from "./WebPaneDragEndEventArgsDetailDescription";
/**
 * @hidden
 */
export let WebPaneDragEndEventArgsDetailDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebPaneDragEndEventArgsDetailDescriptionMetadata extends Base {
        static b(a) {
            if (WebPaneDragEndEventArgsDetailDescriptionMetadata.a == null) {
                WebPaneDragEndEventArgsDetailDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebPaneDragEndEventArgsDetailDescriptionMetadata.c(WebPaneDragEndEventArgsDetailDescriptionMetadata.a);
            }
            if (a.k(WebPaneDragEndEventArgsDetailDescriptionMetadata.a)) {
                return;
            }
            a.ab(WebPaneDragEndEventArgsDetailDescriptionMetadata.a);
            WebDockManagerPaneDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:PaneDragEndEventArgsDetail");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
            a.item("__marshalByValue", "Boolean");
            a.item("__skipSuffix", "Boolean");
            a.item("SourcePane", "ExportedType:WebDockManagerPane");
            a.item("Panes", "Collection:WebContentPane:ContentPaneCollection:WebContentPane");
        }
        static d(a) {
            WebPaneDragEndEventArgsDetailDescriptionMetadata.b(a);
            a.ad("WebPaneDragEndEventArgsDetail", () => new WebPaneDragEndEventArgsDetailDescription());
            a.ac("WebPaneDragEndEventArgsDetail", WebPaneDragEndEventArgsDetailDescriptionMetadata.a);
        }
    }
    WebPaneDragEndEventArgsDetailDescriptionMetadata.$t = markType(WebPaneDragEndEventArgsDetailDescriptionMetadata, 'WebPaneDragEndEventArgsDetailDescriptionMetadata');
    WebPaneDragEndEventArgsDetailDescriptionMetadata.a = null;
    return WebPaneDragEndEventArgsDetailDescriptionMetadata;
})();

==> igniteui-angular-core-20.0.0.tgz: package/esm2015/lib/WebPaneDragEndEventArgsDetailDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebDockManagerPaneDescriptionMetadata } from "./WebDockManagerPaneDescriptionMetadata";
import { WebPaneDragEndEventArgsDetailDescription } from "./WebPaneDragEndEventArgsDetailDescription";
/**
 * @hidden
 */
export let WebPaneDragEndEventArgsDetailDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebPaneDragEndEventArgsDetailDescriptionMetadata extends Base {
        static b(a) {
            if (WebPaneDragEndEventArgsDetailDescriptionMetadata.a == null) {
                WebPaneDragEndEventArgsDetailDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebPaneDragEndEventArgsDetailDescriptionMetadata.c(WebPaneDragEndEventArgsDetailDescriptionMetadata.a);
            }
            if (a.k(WebPaneDragEndEventArgsDetailDescriptionMetadata.a)) {
                return;
            }
            a.ac(WebPaneDragEndEventArgsDetailDescriptionMetadata.a);
            WebDockManagerPaneDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:PaneDragEndEventArgsDetail");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
            a.item("__marshalByValue", "Boolean");
            a.item("__skipSuffix", "Boolean");
            a.item("SourcePane", "ExportedType:WebDockManagerPane");
            a.item("Panes", "Collection:WebContentPane:ContentPaneCollection:WebContentPane");
        }
        static d(a) {
            WebPaneDragEndEventArgsDetailDescriptionMetadata.b(a);
            a.ae("WebPaneDragEndEventArgsDetail", () => new WebPaneDragEndEventArgsDetailDescription());
            a.ad("WebPaneDragEndEventArgsDetail", WebPaneDragEndEventArgsDetailDescriptionMetadata.a);
        }
    }
    WebPaneDragEndEventArgsDetailDescriptionMetadata.$t = markType(WebPaneDragEndEventArgsDetailDescriptionMetadata, 'WebPaneDragEndEventArgsDetailDescriptionMetadata');
    WebPaneDragEndEventArgsDetailDescriptionMetadata.a = null;
    return WebPaneDragEndEventArgsDetailDescriptionMetadata;
})();
